==> libdrm-2.4.68-arm-1.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libdrm_amdgpu.so.1 )
( cd usr/lib ; ln -sf libdrm_amdgpu.so.1.0.0 libdrm_amdgpu.so.1 )
( cd usr/lib ; rm -rf libdrm_freedreno.so )
( cd usr/lib ; ln -sf libdrm_freedreno.so.1.0.0 libdrm_freedreno.so )
( cd usr/lib ; rm -rf libdrm.so.2 )
( cd usr/lib ; ln -sf libdrm.so.2.4.0 libdrm.so.2 )
( cd usr/lib ; rm -rf libdrm_exynos.so )
( cd usr/lib ; ln -sf libdrm_exynos.so.1.0.0 libdrm_exynos.so )
( cd usr/lib ; rm -rf libdrm_nouveau.so )
( cd usr/lib ; ln -sf libdrm_nouveau.so.2.0.0 libdrm_nouveau.so )
( cd usr/lib ; rm -rf libkms.so.1 )
( cd usr/lib ; ln -sf libkms.so.1.0.0 libkms.so.1 )
( cd usr/lib ; rm -rf libdrm_tegra.so )
( cd usr/lib ; ln -sf libdrm_tegra.so.0.0.0 libdrm_tegra.so )
( cd usr/lib ; rm -rf libdrm_radeon.so.1 )
( cd usr/lib ; ln -sf libdrm_radeon.so.1.0.1 libdrm_radeon.so.1 )
( cd usr/lib ; rm -rf libdrm_exynos.so.1 )
( cd usr/lib ; ln -sf libdrm_exynos.so.1.0.0 libdrm_exynos.so.1 )
( cd usr/lib ; rm -rf libkms.so )
( cd usr/lib ; ln -sf libkms.so.1.0.0 libkms.so )
( cd usr/lib ; rm -rf libdrm_amdgpu.so )
( cd usr/lib ; ln -sf libdrm_amdgpu.so.1.0.0 libdrm_amdgpu.so )
( cd usr/lib ; rm -rf libdrm_omap.so )
( cd usr/lib ; ln -sf libdrm_omap.so.1.0.0 libdrm_omap.so )
( cd usr/lib ; rm -rf libdrm_nouveau.so.2 )
( cd usr/lib ; ln -sf libdrm_nouveau.so.2.0.0 libdrm_nouveau.so.2 )
( cd usr/lib ; rm -rf libdrm_omap.so.1 )
( cd usr/lib ; ln -sf libdrm_omap.so.1.0.0 libdrm_omap.so.1 )
( cd usr/lib ; rm -rf libdrm.so )
( cd usr/lib ; ln -sf libdrm.so.2.4.0 libdrm.so )
( cd usr/lib ; rm -rf libdrm_radeon.so )
( cd usr/lib ; ln -sf libdrm_radeon.so.1.0.1 libdrm_radeon.so )
( cd usr/lib ; rm -rf libdrm_freedreno.so.1 )
( cd usr/lib ; ln -sf libdrm_freedreno.so.1.0.0 libdrm_freedreno.so.1 )
( cd usr/lib ; rm -rf libdrm_tegra.so.0 )
( cd usr/lib ; ln -sf libdrm_tegra.so.0.0.0 libdrm_tegra.so.0 )

==> libdrm-2.4.109-arm-1.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libdrm.so )
( cd usr/lib ; ln -sf libdrm.so.2 libdrm.so )
( cd usr/lib ; rm -rf libdrm.so.2 )
( cd usr/lib ; ln -sf libdrm.so.2.4.0 libdrm.so.2 )
( cd usr/lib ; rm -rf libdrm_amdgpu.so )
( cd usr/lib ; ln -sf libdrm_amdgpu.so.1 libdrm_amdgpu.so )
( cd usr/lib ; rm -rf libdrm_amdgpu.so.1 )
( cd usr/lib ; ln -sf libdrm_amdgpu.so.1.0.0 libdrm_amdgpu.so.1 )
( cd usr/lib ; rm -rf libdrm_etnaviv.so )
( cd usr/lib ; ln -sf libdrm_etnaviv.so.1 libdrm_etnaviv.so )
( cd usr/lib ; rm -rf libdrm_etnaviv.so.1 )
( cd usr/lib ; ln -sf libdrm_etnaviv.so.1.0.0 libdrm_etnaviv.so.1 )
( cd usr/lib ; rm -rf libdrm_exynos.so )
( cd usr/lib ; ln -sf libdrm_exynos.so.1 libdrm_exynos.so )
( cd usr/lib ; rm -rf libdrm_exynos.so.1 )
( cd usr/lib ; ln -sf libdrm_exynos.so.1.0.0 libdrm_exynos.so.1 )
( cd usr/lib ; rm -rf libdrm_freedreno.so )
( cd usr/lib ; ln -sf libdrm_freedreno.so.1 libdrm_freedreno.so )
( cd usr/lib ; rm -rf libdrm_freedreno.so.1 )
( cd usr/lib ; ln -sf libdrm_freedreno.so.1.0.0 libdrm_freedreno.so.1 )
( cd usr/lib ; rm -rf libdrm_nouveau.so )
( cd usr/lib ; ln -sf libdrm_nouveau.so.2 libdrm_nouveau.so )
( cd usr/lib ; rm -rf libdrm_nouveau.so.2 )
( cd usr/lib ; ln -sf libdrm_nouveau.so.2.0.0 libdrm_nouveau.so.2 )
( cd usr/lib ; rm -rf libdrm_omap.so )
( cd usr/lib ; ln -sf libdrm_omap.so.1 libdrm_omap.so )
( cd usr/lib ; rm -rf libdrm_omap.so.1 )
( cd usr/lib ; ln -sf libdrm_omap.so.1.0.0 libdrm_omap.so.1 )
( cd usr/lib ; rm -rf libdrm_radeon.so )
( cd usr/lib ; ln -sf libdrm_radeon.so.1 libdrm_radeon.so )
( cd usr/lib ; rm -rf libdrm_radeon.so.1 )
( cd usr/lib ; ln -sf libdrm_radeon.so.1.0.1 libdrm_radeon.so.1 )
( cd usr/lib ; rm -rf libdrm_tegra.so )
( cd usr/lib ; ln -sf libdrm_tegra.so.0 libdrm_tegra.so )
( cd usr/lib ; rm -rf libdrm_tegra.so.0 )
( cd usr/lib ; ln -sf libdrm_tegra.so.0.0.0 libdrm_tegra.so.0 )
( cd usr/lib ; rm -rf libkms.so )
( cd usr/lib ; ln -sf libkms.so.1 libkms.so )
( cd usr/lib ; rm -rf libkms.so.1 )
( cd usr/lib ; ln -sf libkms.so.1.0.0 libkms.so.1 )
